@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package Neo4j::Driver::Net::Bolt 1.01; # TRIAL
+package Neo4j::Driver::Net::Bolt 1.02; # TRIAL
 # ABSTRACT: Network controller for Neo4j Bolt
 
 
@@ -56,7 +56,6 @@ sub new {
 		uri => $uri,
 		result_module => $net_module->can('result_handlers') ? ($net_module->result_handlers)[0] : $RESULT_MODULE,
 		server_info => $driver->{server_info},
-		cypher_types => $driver->{config}->{cypher_types},
 		active_tx => 0,
 	}, $class;
 }
@@ -198,11 +197,14 @@ sub _run {
 			bolt_stream => $stream,
 			bolt_connection => $self->{connection},
 			query => $query,
-			cypher_types => $self->{cypher_types},
 			server_info => $self->{server_info},
 			error_handler => $tx->{error_handler},
 		});
 	}
+	else {
+		$result = Neo4j::Driver::Result->new;
+		$result->{server_info} = $self->{server_info};
+	}
 	
 	return ($result);
 }
