@@ -1,7 +1,7 @@
 use v5.12;
 use warnings;
 
-package Neo4j::Driver::Net::HTTP 1.01; # TRIAL
+package Neo4j::Driver::Net::HTTP 1.02; # TRIAL
 # ABSTRACT: Network controller for Neo4j HTTP
 
 
@@ -14,7 +14,7 @@ our @CARP_NOT = qw(Neo4j::Driver::Transaction Neo4j::Driver::Transaction::HTTP);
 use Time::Piece 1.20 qw();
 use URI 1.31;
 
-use Neo4j::Driver::Net::HTTP::LWP;
+use Neo4j::Driver::Net::HTTP::Tiny;
 use Neo4j::Driver::Result::Jolt;
 use Neo4j::Driver::Result::JSON;
 use Neo4j::Driver::Result::Text;
@@ -35,14 +35,13 @@ sub new {
 	my ($class, $driver) = @_;
 	
 	$driver->{events}->{default_handlers}->{http_adapter_factory} //= sub {
-		my $net_module = $driver->{config}->{net_module} || 'Neo4j::Driver::Net::HTTP::LWP';
+		my $net_module = $driver->{config}->{net_module} || 'Neo4j::Driver::Net::HTTP::Tiny';
 		return $net_module->new($driver);
 	};
 	my $http_adapter = $driver->{events}->trigger('http_adapter_factory', $driver);
 	
 	my $self = bless {
 		events => $driver->{events},
-		cypher_types => $driver->{config}->{cypher_types},
 		server_info => $driver->{server_info},
 		http_agent => $http_adapter,
 		want_jolt => $driver->{config}->{jolt},
@@ -183,7 +182,6 @@ sub _request {
 		http_method => $method,
 		http_path => $tx_endpoint,
 		http_header => $header,
-		cypher_types => $self->{cypher_types},
 		server_info => $self->{server_info},
 		queries => $json ? $json->{statements} : [],
 	});
