@@ -1,31 +1,26 @@
 use v5.12;
 use warnings;
 
-package Neo4j::Driver::Record 1.01; # TRIAL
+package Neo4j::Driver::Record 1.02; # TRIAL
 # ABSTRACT: Container for Cypher result values
 
 
 use Carp qw(croak);
+use List::Util qw(first);
 
 use Neo4j::Driver::ResultSummary;
 
 
-# Based on _looks_like_number() in JSON:PP 4.05, originally by HAARG.
-# Modified on 2020 OCT 13 to detect only integers (column index).
-sub _looks_like_int {
-	my $value = shift;
-	# if the utf8 flag is on, it almost certainly started as a string
-	return if utf8::is_utf8($value);
-	# detect numbers
-	# string & "" -> ""
-	# number & "" -> 0 (with warning)
-	# nan and inf can detect as numbers, so check with * 0
+# Check if the given value was created as a number. Older Perls lack stable
+# tracking of numbers vs. strings, but a quirk of bitwise string operators
+# can be used to determine whether the scalar contains a number (see perlop).
+# That isn't quite the same, but it should be good enough for us.
+# (original idea from https://github.com/makamaka/JSON-PP/commit/87bd6a4)
+sub _SvNIOKp {
 	no warnings 'numeric';
-	return unless length((my $dummy = "") & $value);
-	return unless $value eq int $value;
-	return unless $value * 0 == 0;
-	return 1;
+	return length( (my $string = '') & shift );
 }
+*created_as_number = $^V ge v5.36 ? \&builtin::created_as_number : \&_SvNIOKp;
 
 
 sub get {
@@ -38,43 +33,38 @@ sub get {
 		return $self->{row}->[0];
 	}
 	
-	croak "Field '' not present in query result" if ! length $field;
+	my $index = $self->{field_names_cache}->{$field};
+	return $self->{row}->[$index] if defined $index && length $field;
 	
-	my $unambiguous_key = $self->{column_keys}->{$field};
-	return $self->{row}->[$unambiguous_key] if defined $unambiguous_key;
+	# At this point, it looks like the given $field is both a valid name and
+	# a valid index, which should be pretty rare.
+	# Callers usually specify the field as a literal in the method call, so we
+	# can DWIM and disambiguate by using Perl's created_as_number() built-in.
 	
-	if ( _looks_like_int $field ) {
-		croak sprintf "Field %i not present in query result", $field
-			unless $field >= 0 && $field < @{$self->{row}};
+	no if $^V ge v5.36, 'warnings', 'experimental::builtin';
+	if ( created_as_number($field) ) {
+		croak sprintf "Field %s not present in query result", $field
+			unless $field == int $field && $field >= 0 && $field < @{$self->{row}};
 		return $self->{row}->[$field];
 	}
 	
-	my $key = $self->_field_index( $field );
+	my $field_names = $self->{field_names_cache}->{''};
+	$index = first { $field eq $field_names->[$_] } 0 .. $#$field_names;
 	croak sprintf "Field '%s' not present in query result", $field
-		unless defined $key;
-	return $self->{row}->[$key];
+		unless defined $index;
+	return $self->{row}->[$index];
 }
 
 
 sub data {
 	my ($self) = @_;
 	
-	my %data = ();
-	foreach my $key (keys %{ $self->{column_keys} }) {
-		$data{$key} = $self->{row}->[ $self->_field_index( $key ) ];
-	}
-	return \%data;
-}
-
-
-# Return the index of the given column in the result record array
-sub _field_index {
-	my ($self, $name) = @_;
+	return $self->{hash} if exists $self->{hash};
 	
-	my $cache = $self->{column_keys};
-	return $cache->{$name} if length $name && exists $cache->{$name};
-	return $cache->{''}->{$name} if exists $cache->{''};
-	return undef;
+	my $field_names = $self->{field_names_cache}->{''};
+	my %data;
+	$data{ $field_names->[$_] } = $self->{row}->[$_] for 0 .. $#$field_names;
+	return $self->{hash} = \%data;
 }
 
 
@@ -83,25 +73,23 @@ sub _field_index {
 sub _field_names_cache {
 	my ($result) = @_;
 	
-	croak 'Result missing columns' unless $result && $result->{columns};
-	my $columns = $result->{columns};
-	my $cache = {};
-	for my $index (0 .. $#$columns) {
-		my $name = $columns->[$index];
+	my $field_names = $result->{columns};
+	my $cache = { '' => $field_names };
+	for my $index (0 .. $#$field_names) {
+		my $name = $field_names->[$index];
 		
 		# Create lookup cache for both index and field name to the index.
-		# Move ambiguous index/name pairs to the '' sub-hash.
+		# Skip ambiguous index/name pairs.
 		
 		if ( exists $cache->{$name} ) {
 			delete $cache->{$name};
-			$cache->{''}->{$name} = $index;
 		}
 		else {
 			$cache->{$name} = $index;
 		}
 		
 		if ( exists $cache->{$index} ) {
-			$cache->{''}->{$index} = delete $cache->{$index};
+			delete $cache->{$index};
 		}
 		else {
 			$cache->{$index} = $index;
@@ -119,8 +107,8 @@ sub _field_names_cache {
 
 # Exceptionally, index/name collisions can occur (see record-ambiguous.t).
 # The field names lookup cache is limited to cases where no ambiguity exists.
-# Any field name which would also be a valid index is moved to a sub-hash
-# stored in the entry '' (empty string). Neo4j doesn't allow zero-length
+# A reference to the original list of field names is kept in
+# the entry '' (empty string). Neo4j doesn't allow zero-length
 # field names, so '' itself is never ambiguous.
 
 
@@ -129,8 +117,8 @@ sub summary {
 	my ($self) = @_;
 	warnings::warnif deprecated => "summary() in Neo4j::Driver::Record is deprecated; use consume() in Neo4j::Driver::Result instead";
 	
-	$self->{_summary} //= Neo4j::Driver::ResultSummary->new;
-	return $self->{_summary}->_init;
+	croak 'Summary unavailable for Record retrieved with fetch() or list(); use consume() in Neo4j::Driver::Result' unless $self->{_summary};
+	return $self->{_summary};
 }
 
 
@@ -148,7 +136,7 @@ Neo4j::Driver::Record - Container for Cypher result values
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
