@@ -1,7 +1,7 @@
 use v5.12;
 use warnings;
 
-package Neo4j::Driver::Result 1.01; # TRIAL
+package Neo4j::Driver::Result 1.02; # TRIAL
 # ABSTRACT: Result of running a Cypher query (a stream of records)
 
 
@@ -22,18 +22,10 @@ sub new {
 }
 
 
-sub _column_keys {
-	my ($self) = @_;
-	
-	$self->{columns} //= Neo4j::Driver::Record::_field_names_cache( $self->{result} );
-	return $self->{columns};
-}
-
-
 sub keys {
 	my ($self) = @_;
 	
-	return @{ $self->{result}->{columns} };
+	return @{ $self->{result}->{columns} // [] };
 }
 
 
@@ -58,7 +50,7 @@ sub single {
 	
 	croak 'There is not exactly one result record' if $self->size != 1;
 	my ($record) = $self->list;
-	$record->{_summary} = $self->_summary if $self->{result}->{stats};
+	$record->{_summary} = $self->_summary;
 	return $record;
 }
 
@@ -73,7 +65,7 @@ sub _as_fully_buffered {
 	# buffered right away, avoiding the need to loop through _fetch_next().
 	# (also used in Bolt/Jolt testing, $gather_results 1)
 	$self->{buffer} = $self->{result}->{data};
-	$self->{columns} = Neo4j::Driver::Record::_field_names_cache( $self->{result} );
+	$self->{field_names_cache} = Neo4j::Driver::Record::_field_names_cache( $self->{result} );
 	$self->_init_record( $_ ) for @{ $self->{buffer} };
 	return $self;
 }
@@ -84,7 +76,7 @@ sub _fill_buffer {
 	
 	return 0 unless $self->{attached};
 	
-	$self->_column_keys if $self->{result};
+	$self->{field_names_cache} //= Neo4j::Driver::Record::_field_names_cache( $self->{result} );
 	
 	# try to get at least $minimum records on the buffer
 	my $buffer = $self->{buffer};
@@ -169,7 +161,7 @@ sub _summary {
 	
 	$self->{summary} //= Neo4j::Driver::ResultSummary->new( $self->{result}, $self->{notifications}, $self->{query}, $self->{server_info} );
 	
-	return $self->{summary}->_init;
+	return $self->{summary};
 }
 
 
@@ -199,7 +191,7 @@ Neo4j::Driver::Result - Result of running a Cypher query (a stream of records)
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
