@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package Neo4j::Driver::Result::JSON 1.01; # TRIAL
+package Neo4j::Driver::Result::JSON 1.02; # TRIAL
 # ABSTRACT: JSON/REST result handler
 
 
@@ -15,6 +15,13 @@ our @CARP_NOT = qw(Neo4j::Driver::Net::HTTP);
 use Feature::Compat::Try;
 use JSON::MaybeXS 1.002004 ();
 
+use Neo4j::Driver::Type::Bytes;
+use Neo4j::Driver::Type::DateTime;
+use Neo4j::Driver::Type::Duration;
+use Neo4j::Driver::Type::Path;
+use Neo4j::Driver::Type::Point;
+use Neo4j::Driver::Type::V1::Node;
+use Neo4j::Driver::Type::V1::Relationship;
 use Neo4j::Error;
 
 
@@ -64,9 +71,8 @@ sub _new_result {
 		exhausted => 0,  # 1: all records read by the client; fetch() will fail
 		result => $result,
 		buffer => [],
-		columns => undef,
+		field_names_cache => undef,
 		summary => undef,
-		cypher_types => $params->{cypher_types},
 		notifications => $json->{notifications},
 		server_info => $params->{server_info},
 	};
@@ -139,36 +145,34 @@ sub _info {
 sub _init_record {
 	my ($self, $record) = @_;
 	
-	$record->{column_keys} = $self->{columns};
+	$record->{field_names_cache} = $self->{field_names_cache};
 	$self->_deep_bless( $record->{row}, $record->{meta}, $record->{rest} );
-	$record->{meta} = 'The Neo4j::Driver::Record->{meta} feature was removed';
+	delete $record->{meta};
+	delete $record->{rest};
 	return bless $record, 'Neo4j::Driver::Record';
 }
 
 
 sub _deep_bless {
 	my ($self, $data, $meta, $rest) = @_;
-	my $cypher_types = $self->{cypher_types};
 	
 	# "meta" is broken, so we primarily use "rest", see neo4j #12306
 	
 	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/[^/]+/node/|) {  # node
-		my $node = bless \$data, $cypher_types->{node};
-		$data->{_meta} = $rest->{metadata};
-		$data->{_meta}->{deleted} = $meta->{deleted} if ref $meta eq 'HASH';
-		$cypher_types->{init}->($node) if $cypher_types->{init};
-		return $node;
+		return bless [
+			$rest->{metadata}->{id},
+			$rest->{metadata}->{labels} // [],
+			$data,
+		], 'Neo4j::Driver::Type::V1::Node';
 	}
 	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/[^/]+/relationship/|) {  # relationship
-		my $rel = bless \$data, $cypher_types->{relationship};
-		$data->{_meta} = $rest->{metadata};
-		$rest->{start} =~ m|/([0-9]+)$|;
-		$data->{_meta}->{start} = 0 + $1;
-		$rest->{end} =~ m|/([0-9]+)$|;
-		$data->{_meta}->{end} = 0 + $1;
-		$data->{_meta}->{deleted} = $meta->{deleted} if ref $meta eq 'HASH';
-		$cypher_types->{init}->($rel) if $cypher_types->{init};
-		return $rel;
+		return bless [
+			$rest->{metadata}->{id},
+			do { $rest->{start} =~ m/(\d+)$/a; 0 + $1 },
+			$rest->{metadata}->{type},
+			do { $rest->{end} =~ m/(\d+)$/a; 0 + $1 },
+			$data,
+		], 'Neo4j::Driver::Type::V1::Relationship';
 	}
 	
 	if (ref $data eq 'ARRAY' && ref $rest eq 'HASH') {  # path
@@ -176,42 +180,34 @@ sub _deep_bless {
 		my $path = [];
 		for my $n ( 0 .. $#{ $rest->{nodes} } ) {
 			my $i = $n * 2;
-			my $uri = $rest->{nodes}->[$n];
-			$uri =~ m|/([0-9]+)$|;
-			$data->[$i]->{_meta} = { id => 0 + $1 };
-			$data->[$i]->{_meta}->{deleted} = $meta->[$i]->{deleted} if ref $meta eq 'ARRAY';
-			$path->[$i] = bless \( $data->[$i] ), $cypher_types->{node};
+			$path->[$i] = bless [
+				do { $rest->{nodes}->[$n] =~ m/(\d+)$/a; 0 + $1 },
+				[],  # see neo4j#12613
+				$data->[$i],
+			], 'Neo4j::Driver::Type::V1::Node';
 		}
 		for my $r ( 0 .. $#{ $rest->{relationships} } ) {
 			my $i = $r * 2 + 1;
-			my $uri = $rest->{relationships}->[$r];
-			$uri =~ m|/([0-9]+)$|;
-			$data->[$i]->{_meta} = { id => 0 + $1 };
-			my $rev = $rest->{directions}->[$r] eq '<-' ? -1 : 1;
-			$data->[$i]->{_meta}->{start} = $data->[$i - 1 * $rev]->{_meta}->{id};
-			$data->[$i]->{_meta}->{end} =   $data->[$i + 1 * $rev]->{_meta}->{id};
-			$data->[$i]->{_meta}->{deleted} = $meta->[$i]->{deleted} if ref $meta eq 'ARRAY';
-			$path->[$i] = bless \( $data->[$i] ), $cypher_types->{relationship};
+			my $dir = $rest->{directions}->[$r] eq '->' ? 1 : -1;
+			$path->[$i] = bless [
+				do { $rest->{relationships}->[$r] =~ m/(\d+)$/a; 0 + $1 },
+				$path->[$i - 1 * $dir]->[0],
+				undef,  # see neo4j#12613
+				$path->[$i + 1 * $dir]->[0],
+				$data->[$i],
+			], 'Neo4j::Driver::Type::V1::Relationship';
 		}
-		$path = bless { path => $path }, $cypher_types->{path};
-		$cypher_types->{init}->($_) for $cypher_types->{init} ? ( @$path, $path ) : ();
-		return $path;
+		return bless { '..' => $path }, 'Neo4j::Driver::Type::Path';
 	}
 	
 	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{crs} eq 'HASH') {  # spatial
-		bless $rest, $cypher_types->{point};
-		$cypher_types->{init}->($data) if $cypher_types->{init};
-		return $rest;
+		$rest->{srid} = $rest->{crs}->{srid};
+		return bless $rest, 'Neo4j::Driver::Type::Point';
 	}
 	if (ref $data eq '' && ref $rest eq '' && ref $meta eq 'HASH' && $meta->{type} && $meta->{type} =~ m/date|time|duration/) {  # temporal (depends on meta => doesn't always work)
-		my $type = $cypher_types->{temporal};
-		if ($type eq 'Neo4j::Driver::Type::Temporal') {
-			$type = 'Neo4j::Driver::Type::DateTime';
-			$type = 'Neo4j::Driver::Type::Duration' if $data =~ m/^-?P/;
-		}
-		$data = bless { data => $data, type => $meta->{type} }, $type;
-		$cypher_types->{init}->($data) if $cypher_types->{init};
-		return $data;
+		return bless { T => $data }, $meta->{type} eq 'duration'
+			? 'Neo4j::Driver::Type::Duration'
+			: 'Neo4j::Driver::Type::DateTime';
 	}
 	
 	if (ref $data eq 'ARRAY' && ref $rest eq 'ARRAY') {  # array
