@@ -1,7 +1,7 @@
 use v5.12;
 use warnings;
 
-package Neo4j::Driver::Type::Path 1.01; # TRIAL
+package Neo4j::Driver::Type::Path 1.02; # TRIAL
 # ABSTRACT: Directed sequence of relationships between two nodes
 
 
@@ -9,16 +9,13 @@ package Neo4j::Driver::Type::Path 1.01; # TRIAL
 
 
 use parent 'Neo4j::Types::Path';
-use overload '@{}' => \&_array, fallback => 1;
-
-use Carp qw(croak);
 
 
 sub nodes {
 	my ($self) = @_;
 	
 	my $i = 0;
-	return grep { ++$i & 1 } @{$self->{path}};
+	return grep { ++$i & 1 } @{$self->{'..'}};
 }
 
 
@@ -26,19 +23,14 @@ sub relationships {
 	my ($self) = @_;
 	
 	my $i = 0;
-	return grep { $i++ & 1 } @{$self->{path}};
+	return grep { $i++ & 1 } @{$self->{'..'}};
 }
 
 
 sub elements {
 	my ($self) = @_;
 	
-	return @{$self->{path}};
-}
-
-
-sub _array {
-	croak 'Use elements() to access Neo4j path elements';
+	return @{$self->{'..'}};
 }
 
 
