@@ -1,7 +1,7 @@
 use v5.12;
 use warnings;
 
-package Neo4j::Driver::Type::Point 1.01; # TRIAL
+package Neo4j::Driver::Type::Point 1.02; # TRIAL
 # ABSTRACT: Represents a Neo4j spatial point value
 
 
@@ -14,11 +14,6 @@ use parent 'Neo4j::Types::Point';
 sub _parse {
 	my ($self) = @_;
 	
-	if ( ! exists $self->{'@'} ) {  # JSON format
-		$self->{srid} = $self->{crs}{srid};
-		return;
-	}
-	
 	my ($srid, $x, $y, $z) = $self->{'@'} =~ m/^SRID=([0-9]+);POINT(?: Z)? ?\(([-0-9.]+) ([-0-9.]+)(?: ([-0-9.]+))?\)$/;
 	
 	$self->{srid} = 0 + $srid;
